@@ -10,10 +10,6 @@ from .load_setting import load_setting
 """
 
 
-async def pull_latest(path):
-    await git.Repo(path).remotes.origin.pull()
-
-
 def download_repo_git(url, id, base_path, sec_path):
     print('Download start...')
     if not os.path.exists(base_path + sec_path):  # 不存在该路径，创建该路径
@@ -29,7 +25,7 @@ def download_repo_git(url, id, base_path, sec_path):
                 git.Repo.clone_from(url, base_path + sec_path)
             else:
                 # 如果有旧数据，则拉取git仓库最新更新
-                pull_latest(base_path + sec_path)
+                git.Repo(base_path + sec_path).remotes.origin.pull()
     print('Successfully download/update, the files are as follows:')
     print(os.listdir(base_path + sec_path))
 
@@ -40,7 +36,49 @@ def download_repo(id_or_url: str, url_type='git'):
     url = ''
     id = ''
 
-    # 根据输入的id或url判断是id还是url，并获取对应的url和id
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+# 据输入的id或url判断是id还是url，并获取对应的url和id
     if len(id_or_url) == 6:
         id = id_or_url
         url = get_url_with_id(id)
